@@ -34,6 +34,22 @@ gtags             Manage branch tags.
 visualise         Graphically visualise this branch. 
 """
 
+import os
+import sys
+
+if getattr(sys, "frozen", None) is not None: # we run bzr.exe
+
+    # FIXME: Unless a better packaging solution is found, the following
+    # provides a workaround for https://bugs.launchpad.net/bzr/+bug/388790 Also
+    # see https://code.edge.launchpad.net/~vila/bzr-gtk/388790-windows-setup
+    # for more details about while it's needed.
+
+    # NOTE: _lib must be ahead of bzrlib or sax.saxutils (in olive) fails
+    here = os.path.dirname(__file__)
+    sys.path.insert(0, os.path.join(here, '_lib'))
+    sys.path.append(os.path.join(here, '_lib/gtk-2.0'))
+
+
 import bzrlib
 import bzrlib.api
 from bzrlib import (
@@ -43,9 +59,8 @@ from bzrlib import (
     )
 from bzrlib.commands import plugin_cmds
 
-import os.path
 
-version_info = (0, 97, 0, 'final')
+version_info = (0, 98, 0, 'final', 1)
 
 if version_info[3] == 'final':
     version_string = '%d.%d.%d' % version_info[:3]
@@ -57,6 +72,7 @@ COMPATIBLE_BZR_VERSIONS = [(1, 6, 0), (1, 7, 0), (1, 8, 0), (1, 9, 0),
                            (1, 10, 0), (1, 11, 0), (1, 12, 0), (1, 13, 0),
                            (1, 15, 0),
                            (1, 17, 0),
+                           (2, 1, 0),
                            ]
 
 bzrlib.api.require_any_api(bzrlib, COMPATIBLE_BZR_VERSIONS)
