@@ -45,9 +45,10 @@ from bzrlib.plugins.gtk.window import Window
 class GAnnotateWindow(Window):
     """Annotate window."""
 
-    def __init__(self, all=False, plain=False, parent=None):
+    def __init__(self, all=False, plain=False, parent=None, branch=None):
         self.all = all
         self.plain = plain
+        self._branch = branch
         
         Window.__init__(self, parent)
         
@@ -80,13 +81,17 @@ class GAnnotateWindow(Window):
         try:
             branch.lock_read()
             branch.repository.lock_read()
+            self.dotted = {}
+            revno_map = self.branch.get_revision_id_to_revno_map()
+            for revision_id, revno in revno_map.iteritems():
+                self.dotted[revision_id] = '.'.join(str(num) for num in revno)
             for line_no, (revision, revno, line)\
                     in enumerate(self._annotate(tree, file_id)):
                 if revision.revision_id == last_seen and not self.all:
                     revno = author = ""
                 else:
                     last_seen = revision.revision_id
-                    author = revision.get_apparent_author()
+                    author = ", ".join(revision.get_apparent_authors())
 
                 if revision.revision_id not in self.revisions:
                     self.revisions[revision.revision_id] = revision
@@ -109,6 +114,9 @@ class GAnnotateWindow(Window):
 
         self.annoview.set_model(self.annomodel)
         self.annoview.grab_focus()
+        my_revno = self.dotted.get(self.revision_id, 'current')
+        title = '%s (%s) - gannotate' % (self.tree.id2path(file_id), my_revno)
+        self.set_title(title)
 
     def jump_to_line(self, lineno):
         if lineno > len(self.annomodel) or lineno < 1:
@@ -124,18 +132,6 @@ class GAnnotateWindow(Window):
         self.annoview.set_cursor(row)
         self.annoview.scroll_to_cell(row, use_align=True)
 
-    def _dotted_revnos(self, repository, revision_id):
-        """Return a dict of revision_id -> dotted revno
-        
-        :param repository: The repository to get the graph from
-        :param revision_id: The last revision for which this info is needed
-        """
-        graph = repository.get_revision_graph(revision_id)
-        dotted = {}
-        for n, revision_id, d, revno, e in tsort.merge_sort(graph, 
-            revision_id, generate_revno=True):
-            dotted[revision_id] = '.'.join(str(num) for num in revno)
-        return dotted
 
     def _annotate(self, tree, file_id):
         current_revision = FakeRevision(CURRENT_REVISION)
@@ -143,14 +139,13 @@ class GAnnotateWindow(Window):
         current_revision.timestamp = time.time()
         current_revision.message = '[Not yet committed]'
         current_revision.parent_ids = tree.get_parent_ids()
-        current_revision.properties['branch-nick'] = self.branch.nick
+        current_revision.properties['branch-nick'] = self.branch._get_nick(local=True)
         current_revno = '%d?' % (self.branch.revno() + 1)
         repository = self.branch.repository
         if self.revision_id == CURRENT_REVISION:
             revision_id = self.branch.last_revision()
         else:
             revision_id = self.revision_id
-        dotted = self._dotted_revnos(repository, revision_id)
         revision_cache = RevisionCache(repository, self.revisions)
         for origin, text in tree.annotate_iter(file_id):
             rev_id = origin
@@ -160,7 +155,7 @@ class GAnnotateWindow(Window):
             else:
                 try:
                     revision = revision_cache.get_revision(rev_id)
-                    revno = dotted.get(rev_id, 'merge')
+                    revno = self.dotted.get(rev_id, 'merge')
                     if len(revno) > 15:
                         revno = 'merge'
                 except NoSuchRevision:
@@ -183,7 +178,7 @@ class GAnnotateWindow(Window):
 
     def _activate_selected_revision(self, w):
         rev_id = self._selected_revision()
-        if rev_id is None:
+        if not rev_id or rev_id == NULL_REVISION:
             return
         selected = self.revisions[rev_id]
         self.revisionview.set_revision(selected)
@@ -247,7 +242,7 @@ class GAnnotateWindow(Window):
         self._search.show_for('line')
         self._search.set_target(self.annoview, LINE_NUM_COL)
 
-    def row_diff(self, tv, path, tvc):
+    def line_diff(self, tv, path, tvc):
         row = path[0]
         revision = self.annotations[row]
         repository = self.branch.repository
@@ -262,7 +257,7 @@ class GAnnotateWindow(Window):
                 tree2 = repository.revision_tree(NULL_REVISION)
         from bzrlib.plugins.gtk.diff import DiffWindow
         window = DiffWindow()
-        window.set_diff("Diff for row %d" % (row+1), tree1, tree2)
+        window.set_diff("Diff for line %d" % (row+1), tree1, tree2)
         window.set_file(tree1.id2path(self.file_id))
         window.show()
 
@@ -272,7 +267,7 @@ class GAnnotateWindow(Window):
         tv.set_rules_hint(False)
         tv.connect("cursor-changed", self._activate_selected_revision)
         tv.show()
-        tv.connect("row-activated", self.row_diff)
+        tv.connect("row-activated", self.line_diff)
 
         cell = gtk.CellRendererText()
         cell.set_property("xalign", 1.0)
@@ -326,7 +321,7 @@ class GAnnotateWindow(Window):
         return tv
 
     def _create_log_view(self):
-        lv = RevisionView()
+        lv = RevisionView(self._branch)
         lv.show()
         return lv
 
@@ -394,7 +389,7 @@ class GAnnotateWindow(Window):
                 return j - i
 
 
-class FakeRevision:
+class FakeRevision(object):
     """ A fake revision.
 
     For when a revision is referenced but not present.
@@ -409,12 +404,13 @@ class FakeRevision:
         self.timezone = 0
         self.properties = {}
 
-    def get_apparent_author(self):
-        return self.committer
+    def get_apparent_authors(self):
+        return [self.committer]
 
 
 class RevisionCache(object):
     """A caching revision source"""
+
     def __init__(self, real_source, seed_cache=None):
         self.__real_source = real_source
         if seed_cache is None:
