@@ -21,17 +21,16 @@ except:
     pass
 
 import gtk
-import gtk.glade
 
 
-def _message_dialog(type, primary, secondary, buttons=gtk.BUTTONS_OK):
+def _message_dialog(type, primary, secondary, parent=None, buttons=gtk.BUTTONS_OK):
     """ Display a given type of MessageDialog with the given message.
     
     :param type: message dialog type
     
     :param message: the message you want to display.
     """
-    dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL, type=type,
+    dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL, type=type, parent=parent,
                                buttons=buttons)
     dialog.set_markup('<big><b>' + primary + '</b></big>')
     dialog.format_secondary_markup(secondary)
@@ -39,18 +38,18 @@ def _message_dialog(type, primary, secondary, buttons=gtk.BUTTONS_OK):
     dialog.destroy()
     return response
 
-def error_dialog(primary, secondary):
+def error_dialog(primary, secondary, parent=None):
     """ Display an error dialog with the given message. """
-    return _message_dialog(gtk.MESSAGE_ERROR, primary, secondary)
+    return _message_dialog(gtk.MESSAGE_ERROR, primary, secondary, parent)
 
-def info_dialog(primary, secondary):
+def info_dialog(primary, secondary, parent=None):
     """ Display an info dialog with the given message. """
-    return _message_dialog(gtk.MESSAGE_INFO, primary, secondary)
+    return _message_dialog(gtk.MESSAGE_INFO, primary, secondary, parent)
 
-def warning_dialog(primary, secondary):
+def warning_dialog(primary, secondary, parent=None):
     """ Display a warning dialog with the given message. """
-    return _message_dialog(gtk.MESSAGE_WARNING, primary, secondary)
+    return _message_dialog(gtk.MESSAGE_WARNING, primary, secondary, parent)
 
-def question_dialog(primary, secondary):
+def question_dialog(primary, secondary, parent=None):
     """ Display a dialog with the given question. """
-    return _message_dialog(gtk.MESSAGE_QUESTION, primary, secondary, gtk.BUTTONS_YES_NO)
+    return _message_dialog(gtk.MESSAGE_QUESTION, primary, secondary, parent, gtk.BUTTONS_YES_NO)
