@@ -60,16 +60,14 @@ def about():
     """ Display the AboutDialog. """
     from bzrlib.plugins.gtk import __version__, icon_path
     
-    iconpath = icon_path() + os.sep
-    
     dialog = gtk.AboutDialog()
     dialog.set_name("Olive")
     dialog.set_version(__version__)
-    dialog.set_copyright("Copyright (C) 2006 Szilveszter Farkas (Phanatic)")
-    dialog.set_website("https://launchpad.net/products/olive")
-    dialog.set_website_label("https://launchpad.net/products/olive")
-    dialog.set_icon_from_file(iconpath+"oliveicon2.png")
-    dialog.set_logo(gtk.gdk.pixbuf_new_from_file(iconpath+"oliveicon2.png"))
+    dialog.set_copyright("Copyright (C) 2006-2008 Szilveszter Farkas (Phanatic)")
+    dialog.set_website("https://launchpad.net/bzr-gtk")
+    dialog.set_website_label("https://launchpad.net/bzr-gtk")
+    dialog.set_icon_from_file(icon_path("oliveicon2.png"))
+    dialog.set_logo(gtk.gdk.pixbuf_new_from_file(icon_path("oliveicon2.png")))
     dialog.set_authors([ _i18n("Lead Developer:"),
 			 "Szilveszter Farkas <szilveszter.farkas@gmail.com>",
 			 _i18n("Contributors:"),
@@ -83,6 +81,7 @@ def about():
     # Destroy the dialog
     dialog.destroy()
 
+
 class OliveGtk:
     """ The main Olive GTK frontend class. This is called when launching the
     program. """
@@ -134,9 +133,6 @@ class OliveGtk:
             self.combobox_drive.show()
             self.gen_hard_selector()
         
-        # Acceptable errors when loading files/folders in the treeviews
-        self.acceptable_errors = (errno.ENOENT, errno.ELOOP)
-        
         self.refresh_left()
 
         # Apply menu state
@@ -532,7 +528,7 @@ class OliveGtk:
         
     @show_bzr_error
     def on_menuitem_branch_update_activate(self, widget):
-        """ Brranch/checkout update menu handler. """
+        """ Branch/checkout update menu handler. """
         
         ret = self.wt.update()
         conflicts = self.wt.conflicts()
@@ -540,6 +536,7 @@ class OliveGtk:
             info_dialog(_i18n('Update successful but conflicts generated'), _i18n('Number of conflicts generated: %d.') % (len(conflicts),) )
         else:
             info_dialog(_i18n('Update successful'), _i18n('No conflicts generated.') )
+        self.refresh_right()
     
     def on_menuitem_branch_push_activate(self, widget):
         """ Branch/Push... menu handler. """
@@ -562,11 +559,9 @@ class OliveGtk:
     
     def on_menuitem_branch_status_activate(self, widget):
         """ Branch/Status... menu handler. """
-        from bzrlib.plugins.gtk.status import StatusDialog
-        status = StatusDialog(self.wt, self.wtpath)
-        response = status.run()
-        if response != gtk.RESPONSE_NONE:
-            status.destroy()
+        from bzrlib.plugins.gtk.status import StatusWindow
+        status = StatusWindow(self.wt, self.wtpath)
+        status.show()
     
     def on_menuitem_branch_initialize_activate(self, widget):
         """ Initialize current directory. """
@@ -660,7 +655,6 @@ class OliveGtk:
             remove.hide()
         
             if response == gtk.RESPONSE_OK:
-                self.set_path(self.path)
                 self.refresh_right()
             
             remove.destroy()
@@ -669,7 +663,8 @@ class OliveGtk:
         """ Statistics/Differences... menu handler. """
         window = DiffWindow(parent=self.window)
         parent_tree = self.wt.branch.repository.revision_tree(self.wt.branch.last_revision())
-        window.set_diff(self.wt.branch.nick, self.wt, parent_tree)
+        window.set_diff(self.wt.branch._get_nick(local=True), self.wt, 
+                        parent_tree)
         window.show()
     
     def on_menuitem_stats_infos_activate(self, widget):
@@ -703,12 +698,14 @@ class OliveGtk:
     def on_menuitem_view_show_hidden_files_activate(self, widget):
         """ View/Show hidden files menu handler. """
         self.pref.set_preference('dotted_files', widget.get_active())
+        self.pref.write()
         if self.path is not None:
             self.refresh_right()
 
     def on_menuitem_view_show_ignored_files_activate(self, widget):
         """ Hide/Show ignored files menu handler. """
         self.pref.set_preference('ignored_files', widget.get_active())
+        self.pref.write()
         if self.path is not None:
             self.refresh_right()
             
@@ -875,7 +872,7 @@ class OliveGtk:
         
         self.pref.write()
         self.window.destroy()
-    
+
     def get_selected_fileid(self):
         """ Get the file_id of the selected file. """
         treeselection = self.window.treeview_right.get_selection()
@@ -940,32 +937,33 @@ class OliveGtk:
         for title_item in bookmarks:
             liststore.append(title_item)
         
-        # Add the ListStore to the TreeView
+        # Add the ListStore to the TreeView and refresh column width
         self.window.treeview_left.set_model(liststore)
+        self.window.treeview_left.columns_autosize()
 
     def refresh_right(self):
         """ Refresh the file list. """
         if not self.remote:
             # We're local
             from bzrlib.workingtree import WorkingTree
-    
+            
             path = self.get_path()
             
             # Get ListStore and clear it
             liststore = self.window.filelist
             liststore.clear()
-    
+            
             dirs = []
             files = []
-    
+            
             # Fill the appropriate lists
             dotted_files = self.pref.get_preference('dotted_files', 'bool')
             ignored_files = self.pref.get_preference('ignored_files', 'bool')
-
+            
             for item in os.listdir(path):
                 if not dotted_files and item[0] == '.':
                     continue
-                if os.path.isdir(path + os.sep + item):
+                if os.path.isdir(os.path.join(path, item)):
                     dirs.append(item)
                 else:
                     files.append(item)
@@ -976,7 +974,7 @@ class OliveGtk:
                     tree1 = WorkingTree.open_containing(os.path.realpath(path))[0]
                     branch = tree1.branch
                     tree2 = tree1.branch.repository.revision_tree(branch.last_revision())
-                
+                    
                     delta = tree1.changes_from(tree2, want_unchanged=True)
                     
                     # Show Status column
@@ -1001,13 +999,7 @@ class OliveGtk:
                     if not ignored_files and status == 'ignored':
                         continue
                 
-                try:
-                    statinfo = os.stat(self.path + os.sep + item)
-                except OSError, e:
-                    if e.errno in self.acceptable_errors:
-                        continue
-                    else:
-                        raise
+                statinfo = os.lstat(os.path.join(self.path, item))
                 liststore.append([ gtk.STOCK_DIRECTORY,
                                    True,
                                    item,
@@ -1029,13 +1021,7 @@ class OliveGtk:
                     if not ignored_files and status == 'ignored':
                         continue
                 
-                try:
-                    statinfo = os.stat(self.path + os.sep + item)
-                except OSError, e:
-                    if e.errno in self.acceptable_errors:
-                        continue
-                    else:
-                        raise
+                statinfo = os.lstat(os.path.join(self.path, item))
                 liststore.append([gtk.STOCK_FILE,
                                   False,
                                   item,
