@@ -22,8 +22,12 @@ import pango
 import gobject
 import webbrowser
 
+from bzrlib import trace
 from bzrlib.osutils import format_date
-from bzrlib.util.bencode import bdecode
+try:
+    from bzrlib.bencode import bdecode
+except ImportError:
+    from bzrlib.util.bencode import bdecode
 from bzrlib.testament import Testament
 
 from bzrlib.plugins.gtk import icon_path
@@ -415,17 +419,25 @@ class RevisionView(gtk.Notebook):
             self.timestamp.set_text(format_date(revision.timestamp,
                                                 revision.timezone))
         try:
-            self.branchnick_label.set_text(revision.properties['branch-nick'])
+            self.branchnick.show()
+            self.branchnick_label.show()
+            self.branchnick.set_text(revision.properties['branch-nick'])
         except KeyError:
-            self.branchnick_label.set_text("")
+            self.branchnick.hide()
+            self.branchnick_label.hide()
 
         self._add_parents_or_children(revision.parent_ids,
                                       self.parents_widgets,
                                       self.parents_table)
-        
+
         file_info = revision.properties.get('file-info', None)
         if file_info is not None:
-            file_info = bdecode(file_info.encode('UTF-8'))
+            try:
+                file_info = bdecode(file_info.encode('UTF-8'))
+            except ValueError:
+                trace.note('Invalid per-file info for revision:%s, value: %r',
+                           revision.revision_id, file_info)
+                file_info = None
 
         if file_info:
             if self._file_id is None:
@@ -617,19 +629,19 @@ class RevisionView(gtk.Notebook):
         self.committer.show()
 
         row += 1
-        label = gtk.Label()
-        label.set_alignment(1.0, 0.5)
-        label.set_markup("<b>Branch nick:</b>")
-        self.table.attach(label, 0, 1, row, row+1, gtk.FILL, gtk.FILL)
-        label.show()
-
         self.branchnick_label = gtk.Label()
-        self.branchnick_label.set_ellipsize(pango.ELLIPSIZE_MIDDLE)
-        self.branchnick_label.set_alignment(0.0, 0.5)
-        self.branchnick_label.set_selectable(True)
-        self.table.attach(self.branchnick_label, 1, 2, row, row+1, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        self.branchnick_label.set_alignment(1.0, 0.5)
+        self.branchnick_label.set_markup("<b>Branch nick:</b>")
+        self.table.attach(self.branchnick_label, 0, 1, row, row+1, gtk.FILL, gtk.FILL)
         self.branchnick_label.show()
 
+        self.branchnick = gtk.Label()
+        self.branchnick.set_ellipsize(pango.ELLIPSIZE_MIDDLE)
+        self.branchnick.set_alignment(0.0, 0.5)
+        self.branchnick.set_selectable(True)
+        self.table.attach(self.branchnick, 1, 2, row, row+1, gtk.EXPAND | gtk.FILL, gtk.FILL)
+        self.branchnick.show()
+
         row += 1
         label = gtk.Label()
         label.set_alignment(1.0, 0.5)
