@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Jelmer Vernooij <jelmer@samba.org>
+# Copyright (C) 2007, 2008 Jelmer Vernooij <jelmer@samba.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,24 +14,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from unittest import TestLoader, TestSuite
-from bzrlib.tests import TestUtil
-
-import os
-
-def test_suite():
-    result = TestSuite()
-
-    loader = TestUtil.TestLoader()
+from bzrlib import tests
 
+def load_tests(basic_tests, module, loader):
     testmod_names = [
+        'test_annotate_config',
         'test_commit',
         'test_diff',
+        'test_history',
         'test_linegraph',
         'test_preferences',
-        'test_history',
+        'test_revisionview',
         ]
 
-    result.addTest(loader.loadTestsFromModuleNames(["%s.%s" % (__name__, i) for i in testmod_names]))
-    return result
-
+    basic_tests.addTest(loader.loadTestsFromModuleNames(
+            ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
+    return basic_tests
